@@ -5,7 +5,7 @@ function(x, fun, ..., cores=1, filename="", overwrite=FALSE, wopt=list())  {
 	txtfun <- .makeTextFun(match.fun(fun))
 	if (inherits(txtfun, "character")) { 
 		if (txtfun %in% c("max", "min", "mean", "range", "prod", "sum", "any", "all")) {
-			opt <- spatOptions(filename, overwrite, wopt)
+			opt <- spatOptions(filename, overwrite, wopt=wopt)
 			na.rm <- isTRUE(list(...)$na.rm)
 			x@ptr <- x@ptr$summary(txtfun, na.rm, opt)
 			return(messages(x, "app"))
@@ -49,7 +49,7 @@ function(x, fun, ..., cores=1, filename="", overwrite=FALSE, wopt=list())  {
 		}
 	}
 
-	b <- writeStart(out, filename, overwrite, wopt)
+	b <- writeStart(out, filename, overwrite, wopt=wopt)
 	if (cores > 1) {
 		cls <- parallel::makeCluster(cores)
 		on.exit(parallel::stopCluster(cls))
@@ -163,10 +163,10 @@ function(x, fun, ..., cores=1, filename="", overwrite=FALSE, wopt=list())  {
 	txtfun <- .makeTextFun(match.fun(fun))
 	if (inherits(txtfun, "character")) { 
 		if (txtfun %in% c("max", "min", "mean", "range", "prod", "sum", "any", "all")) {
-			opt <- spatOptions(filename, overwrite, wopt)
+			opt <- spatOptions(filename, overwrite, wopt=wopt)
 			narm <- isTRUE(list(...)$na.rm)
 			r <- rast()
-			opt <- spatOptions("", TRUE, list())
+			opt <- spatOptions()
 			r@ptr <- x@ptr$summary(txtfun, narm, opt)
 			return (messages(r, "app") )
 		}
@@ -186,7 +186,7 @@ function(x, fun, ..., cores=1, filename="", overwrite=FALSE, wopt=list())  {
 	if (length(test$names == test$nl)) {
 		if (is.null(wopt$names)) wopt$names <- test$names
 	}
-	b <- writeStart(out, filename, overwrite, wopt)
+	b <- writeStart(out, filename, overwrite, wopt=wopt)
 
 	if (cores > 1) {
 		cls <- parallel::makeCluster(cores)
@@ -212,7 +212,7 @@ function(x, fun, ..., cores=1, filename="", overwrite=FALSE, wopt=list())  {
 			writeValues(out, r, b$row[i], b$nrows[i])
 		}
 	}
-	readStop(x)
+#	readStop(x)
 	out <- writeStop(out)
 	return(out)
 }
