@@ -44,25 +44,51 @@
 
 
 setMethod("autocor", signature(x="numeric"), 
-	function(x, w, method="moran", global=TRUE) {
+	function(x, w, method="moran") {
+		method <- match.arg(tolower(method), c("moran", "geary", "gi", "gi*"))
 		d <- dim(w)
-		if ((d[1] != d[2]) || (d[1] != length(x))) {
+		n <- length(x)
+		if ((d[1] != d[2]) || (d[1] != n)) {
 			stop("w must be a square matrix with sides the size of x")
 		}
-		if (global) {
-			n <- length(x)
+		if (method == "moran") {
 			dx <- x - mean(x, na.rm=TRUE)
-			if (method == "moran") {
-				pm <- matrix(rep(dx, each=n) * dx, ncol=n)
-				(n / sum(dx^2)) * sum(pm * w) / sum(w)
-			} else {
-				pm <- matrix(rep(dx, each=n) - dx, ncol=n)^2
-				((n-1)/sum((dx)^2)) * sum(w * pm) / (2 * sum(w))
+			pm <- matrix(rep(dx, each=n) * dx, ncol=n)
+			(n / sum(dx^2)) * sum(pm * w) / sum(w)
+		} else if (method == "geary") { # geary
+			dx <- x - mean(x, na.rm=TRUE)
+			pm <- matrix(rep(dx, each=n) - dx, ncol=n)^2
+			((n-1)/sum((dx)^2)) * sum(w * pm) / (2 * sum(w))
+		} else if (method == "gi") {
+			diag(w) <- 0
+			Gi <- colSums(x * w) / (sum(x)-x)
+			Ei <- rowSums(w) / (n-1) 
+
+			# variance following spdep::localG
+			xibar <- (sum(x) - x)/(n - 1)
+		    si2 <- (sum(x^2) - x^2)/(n - 1) - xibar^2
+			VG <- si2 * (((n - 1) * rowSums(w^2) - rowSums(w)^2)/(n - 2))
+			VG <- VG/((sum(x) - x)^2)
+
+			(Gi-Ei)/sqrt(VG)
+
+		} else if (method == "gi*") {
+			if (any(diag(w) == 0)) {
+				warn("autocor", "it is unexpected that a weight matrix for Gi* has diagonal values that are zero")
 			}
+			Gi <- colSums(x * w) / sum(x)
+			Ei <- rowSums(w) / n
+			# variance following spdep::localG
+			si2 <- sum(scale(x, scale = FALSE)^2)/n
+			VG <- (si2 * ((n * rowSums(w^2) - rowSums(w)^2)/(n - 1))) / (sum(x)^2)
+
+			(Gi-Ei)/sqrt(VG)
+
+			
 		} else {
-			stop("local not yet implemented")			
+			stop()
 		}
-	}
+ 	} 
 )
 
 
@@ -70,6 +96,8 @@ setMethod("autocor", signature(x="numeric"),
 setMethod("autocor", signature(x="SpatRaster"), 
 	function(x, w=matrix(c(1,1,1,1,0,1,1,1,1),3), method="moran", global=TRUE) {
 
+		method <- match.arg(tolower(method), c("moran", "geary"))
+
 		if (nlyr(x) > 1) {
 			warn("autocor", "only the first layer of x is used")
 			x <- x[[1]]
@@ -87,7 +115,7 @@ setMethod("autocor", signature(x="SpatRaster"),
 				W <- focal( zz, w=w, fun="sum") 
 				NS0 <- n / unlist(global(W, "sum", na.rm=TRUE))
 				NS0 * wZiZj / z2
-			} else {
+			} else { # geary
 				w <- .getFilter(w, warn=FALSE)
 				i <- trunc(length(w)/2)+1 
 				n <- ncell(x) - unlist(global(is.na(x), "sum"))
@@ -103,7 +131,7 @@ setMethod("autocor", signature(x="SpatRaster"),
 			if (method == "moran") {	
 				z <- x - unlist(global(x, "mean", na.rm=TRUE))
 				zz <- ifel(is.na(x), NA, 1)
-				W  <- focal( zz, w=w, na.rm=TRUE, pad=TRUE)		
+				W  <- focal(zz, w=w, na.rm=TRUE)		
 				lz <- focal(z, w=w, na.rm=TRUE) / W
 					
 				n <- ncell(x) - unlist(global(is.na(x), "sum", na.rm=TRUE))
