@@ -12,7 +12,7 @@
  
 
 .as.image <- function(x, maxcells=10000) {
-	x <- spatSample(x, size=maxcells, as.raster=TRUE)
+	x <- spatSample(x, size=maxcells, method="regular", as.raster=TRUE)
 	X <- xFromCol(x, 1:ncol(x))
 	Y <- yFromRow(x, nrow(x):1)
 	Z <- t(as.matrix(x, wide=TRUE)[nrow(x):1,]) 
@@ -21,12 +21,12 @@
  
  
 setMethod("as.polygons", signature(x="SpatRaster"), 
-	function(x, trunc=TRUE, dissolve=TRUE, values=TRUE, extent=FALSE, ...) {
+	function(x, trunc=TRUE, dissolve=TRUE, values=TRUE, extent=FALSE) {
 		p <- methods::new("SpatVector")
 		if (extent) {
 			p@ptr <- x@ptr$dense_extent()
 		} else {
-			opt <- spatOptions("", TRUE, list())
+			opt <- spatOptions()
 			p@ptr <- x@ptr$as_polygons(trunc[1], dissolve[1], values[1], TRUE, opt)
 			#x <- messages(x)
 		}
@@ -35,7 +35,7 @@ setMethod("as.polygons", signature(x="SpatRaster"),
 )
 
 setMethod("as.polygons", signature(x="SpatExtent"), 
-	function(x, crs="", ...) {
+	function(x, crs="") {
 		p <- methods::new("SpatVector")
 		p@ptr <- SpatVector$new(x@ptr, crs)
 		messages(p, "as.polygons")
@@ -43,22 +43,22 @@ setMethod("as.polygons", signature(x="SpatExtent"),
 )
 
 setMethod("as.lines", signature(x="SpatExtent"), 
-	function(x, crs="", ...) {
-		as.lines(as.polygons(x, crs, ...))
+	function(x, crs="") {
+		as.lines(as.polygons(x, crs))
 	}
 )
 
 
 setMethod("as.points", signature(x="SpatExtent"), 
-	function(x, crs="", ...) {
+	function(x, crs="") {
 		#vect(do.call(cbind, x@ptr$as.points()), "points", crs=crs)
-		as.points(as.polygons(x, crs, ...))
+		as.points(as.polygons(x, crs))
 	}
 )
 
 
 setMethod("as.lines", signature(x="SpatVector"), 
-	function(x, ...) {
+	function(x) {
 		x@ptr <- x@ptr$as_lines()
 		messages(x, "as.lines")
 	}
@@ -66,7 +66,7 @@ setMethod("as.lines", signature(x="SpatVector"),
 
 
 setMethod("as.points", signature(x="SpatVector"), 
-	function(x, multi=FALSE, ...) {
+	function(x, multi=FALSE) {
 		opt <- .getOptions()
 		x@ptr <- x@ptr$as_points(multi)
 		messages(x, "as.points")
@@ -75,7 +75,7 @@ setMethod("as.points", signature(x="SpatVector"),
 
 
 setMethod("as.points", signature(x="SpatRaster"), 
-	function(x, values=TRUE, ...) {
+	function(x, values=TRUE) {
 		p <- methods::new("SpatVector")
 		opt <- .getOptions()
 		p@ptr <- x@ptr$as_points(values, TRUE, opt)
@@ -98,7 +98,7 @@ setMethod("as.vector", signature(x="SpatExtent"),
 
 
 setMethod("as.character", signature(x="SpatExtent"), 
-	function(x, ...) {
+	function(x) {
 		e <- as.vector(x)
 		paste0("ext(", paste(e, collapse=", "), ")")
 	}
@@ -112,22 +112,22 @@ setMethod("as.vector", signature(x="SpatRaster"),
 
 
 setMethod("as.matrix", signature(x="SpatRaster"), 
-	function(x, wide=FALSE, ...) {
+	function(x, wide=FALSE) {
 		if (!hasValues(x)) {
 			error("as.matrix", "SpatRaster has no cell values")
 		}
 		if (wide) {
 			if (nlyr(x) > 1) {
-				m <- values(x, matrix=TRUE)
+				m <- values(x, mat=TRUE)
 				m <- lapply(1:ncol(m), function(i) {
-					matrix(m[,i],nrow=nrow(x),byrow=TRUE)
+					matrix(m[,i], nrow=nrow(x), byrow=TRUE)
 					})
 				m <- do.call(cbind, m)
 			} else {
-				m <- matrix(values(x, matrix=FALSE),nrow=nrow(x),byrow=TRUE)
+				m <- matrix(values(x, mat=FALSE),nrow=nrow(x),byrow=TRUE)
 			}
 		} else {
-			m <- values(x, matrix=TRUE)
+			m <- values(x, mat=TRUE)
 		}
 		m
 	}
@@ -135,7 +135,7 @@ setMethod("as.matrix", signature(x="SpatRaster"),
 
 
 setMethod("as.data.frame", signature(x="SpatRaster"), 
-	function(x, xy=FALSE, cells=FALSE, na.rm=TRUE, ...) {
+	function(x, xy=FALSE, cells=FALSE, na.rm=TRUE) {
 		d <- NULL
 		if (xy) {
 			d <- xyFromCell(x, 1:ncell(x))
@@ -143,7 +143,7 @@ setMethod("as.data.frame", signature(x="SpatRaster"),
 		if (cells) {
 			d <- cbind(cell=1:ncell(x), d)
 		}
-		d <- cbind(d, values(x, matrix=TRUE))
+		d <- cbind(d, values(x, mat=TRUE))
 		if (na.rm) d <- stats::na.omit(d) 
 		data.frame(d)
 	}
@@ -162,7 +162,7 @@ setAs("SpatVector", "data.frame",
 )
 
 setMethod("as.array", signature(x="SpatRaster"), 
-	function(x, ...) {
+	function(x) {
 		dm <- dim(x)
 		x <- values(x, TRUE)
 		a <- array(NA, dm)
@@ -312,30 +312,38 @@ setAs("SpatRaster", "Raster",
 
 # from sf. first incomplete draft
 .from_sf <- function(from) {
-	i <- attr(from, "sf_column")
-	geom <- from[[i]]
+	sfi <- attr(from, "sf_column")
+	geom <- from[[sfi]]
 	crs <- attr(geom, "crs")$wkt
 	attr(geom, "class") <- NULL
 	types <- t(sapply(geom, function(i) attr(i, "class")))
 	v <- list()
 	for (i in 1:length(geom)) {
-		vv <- list()
-		for (j in 1:length(geom[[i]])) {
-			if (inherits(geom[[1]][[1]], "list")) {
-				vvv <- list()
-				for (k in 1:length(geom[[i]][[j]])) {
-					vvv[[k]] <- cbind(i, j, geom[[i]][[j]][[k]], hole= k!=1) 
+		if (inherits(geom[[i]], "POINT")) {
+			v[[i]] <- cbind(i, 1, geom[[i]][1], geom[[i]][2], hole=0)				
+		} else {
+			vv <- list()
+			for (j in 1:length(geom[[i]])) {
+				if (inherits(geom[[i]][[j]], "list")) {
+					vvv <- list()
+					for (k in 1:length(geom[[i]][[j]])) {
+						vvv[[k]] <- cbind(i, j, geom[[i]][[j]][[k]], hole=k-1) 
+					}
+					vv[[j]] <- do.call(rbind, vvv)
+				} else {
+					vv[[j]] <- cbind(i, j, geom[[i]][[j]], hole=0)
 				}
-				vv[[j]] <- do.call(rbind, vvv)
-			} else {
-				vv[[j]] <- cbind(i, j, geom[[i]][[j]], hole=0) 
 			}
+			v[[i]] <- do.call(rbind, vv)
 		}
-		v[[i]] <- do.call(rbind, vv)
 	}
 	v <- do.call(rbind, v)
+	if (ncol(v) > 5) {
+		v <- cbind(v[,1:4], v[,ncol(v),drop=FALSE])
+		warn("as", "Z/M dimension dropped")
+	}
 	colnames(v)[1:4] <- c("id", "part", "x", "y")
-	types <- unique(types[,2])
+	types <- unique(gsub("MULTI", "", unique(types[,2])))
 	if (length(types) > 1) {
 		error("as,sf", "SpatVector currently only accepts one geometry type")
 	}
@@ -347,7 +355,7 @@ setAs("SpatRaster", "Raster",
 		gt = "polygons"
 	}
 	if (ncol(from) > 1) {
-		from[[i]] <- NULL
+		from[[sfi]] <- NULL
 		d <- as.data.frame(from)
 		vect(v, type=gt, att=d, crs=crs)
 	} else {
@@ -362,10 +370,10 @@ setAs("SpatRaster", "Raster",
 	for (i in 1:length(geom)) {
 		vv <- list()
 		for (j in 1:length(geom[[i]])) {
-			if (inherits(geom[[1]][[1]], "list")) {
+			if (inherits(geom[[i]][[j]], "list")) {
 				vvv <- list()
 				for (k in 1:length(geom[[i]][[j]])) {
-					vvv[[k]] <- cbind(i, j, geom[[i]][[j]][[k]], hole= k!=1) 
+					vvv[[k]] <- cbind(i, j, geom[[i]][[j]][[k]], hole= k-1) 
 				}
 				vv[[j]] <- do.call(rbind, vvv)
 			} else {
@@ -376,8 +384,9 @@ setAs("SpatRaster", "Raster",
 	}
 	v <- do.call(rbind, v)
 	colnames(v)[1:4] <- c("id", "part", "x", "y")
-	if (ncol(v) == 6) {
-		v <- v[,-5]
+	if (ncol(v) > 5) {
+		v <- cbind(v[,1:4], v[,ncol(v),drop=FALSE])
+		warn("as", "Z/M dimension dropped")
 	}
 	types <- class(from)[1]
 	if (grepl("POINT", types, fixed=TRUE)) {
@@ -392,6 +401,33 @@ setAs("SpatRaster", "Raster",
 
 
 
+.from_sfg <- function(from) {
+	geom = from
+	v <- list()
+	for (i in 1:length(geom)) {
+		vv <- list()
+		for (j in 1:length(geom[[i]])) {
+			vv[[j]] <- cbind(i, j, geom[[i]][[j]], hole= j-1) 
+		}
+		v[[i]] <- do.call(rbind, vv)
+	}
+	v <- do.call(rbind, v)
+	colnames(v)[1:4] <- c("id", "part", "x", "y")
+	if (ncol(v) == 6) {
+		v <- v[,-5]
+	}
+	types <- class(geom)[2]
+	if (grepl("POINT", types, fixed=TRUE)) {
+		gt = "points"
+	} else if (grepl("LINE", types, fixed=TRUE)) {
+		gt = "lines"
+	} else if (grepl("POLY", types, fixed=TRUE)) {
+		gt = "polygons"
+	}
+	vect(v, type=gt, crs="")
+}
+
+
 setAs("sf", "SpatVector", 
 	function(from) {
 		v <- try(.from_sf(from), silent=TRUE)
@@ -402,6 +438,17 @@ setAs("sf", "SpatVector",
 	}
 )
 
+setAs("sfc", "SpatVector", 
+	function(from) {
+		v <- try(.from_sfc(from), silent=TRUE)
+		if (inherits(v, "try-error")) {
+			error("as,sfc", "coercion failed. You can try coercing via a Spatial* (sp) class")
+		} 
+		v
+	}
+)
+
+
 
 setAs("im", "SpatRaster", 
 	function(from) {
@@ -415,7 +462,7 @@ setAs("im", "SpatRaster",
 setAs("SpatVector", "Spatial", 
 	function(from) {
 		g <- geom(from, df=TRUE)
-		raster::geom(g, values(from), geomtype(from), .proj4(from))
+		raster::geom(g, values(from), geomtype(from), crs(from))
 	}
 )
 
