@@ -5,8 +5,8 @@
 
 
 setMethod("distance", signature(x="SpatRaster", y="missing"), 
-	function(x, y, grid=FALSE, filename="", overwrite=FALSE, wopt=list(), ...) {
-		opt <- spatOptions(filename, overwrite, wopt=list())
+	function(x, y, grid=FALSE, filename="", ...) {
+		opt <- spatOptions(filename, ...)
 		if (grid) {
 			x@ptr <- x@ptr$gridDistance(opt)
 		} else {
@@ -19,8 +19,8 @@ setMethod("distance", signature(x="SpatRaster", y="missing"),
 
 
 setMethod("buffer", signature(x="SpatRaster"), 
-	function(x, width, filename="", overwrite=FALSE, wopt=list(), ...) {
-		opt <- spatOptions(filename, overwrite, wopt=list())
+	function(x, width, filename="", ...) {
+		opt <- spatOptions(filename, ...)
 		x@ptr <- x@ptr$buffer(width, opt)
 		messages(x, "buffer")
 	}
@@ -28,8 +28,8 @@ setMethod("buffer", signature(x="SpatRaster"),
 
 
 setMethod("distance", signature(x="SpatRaster", y="SpatVector"), 
-	function(x, y, filename="", overwrite=FALSE, wopt=list(), ...) {
-		opt <- spatOptions(filename, overwrite, wopt=list())
+	function(x, y, filename="", ...) {
+		opt <- spatOptions(filename, ...)
 		x@ptr <- x@ptr$vectDistance(y@ptr, opt)
 		messages(x, "distance")
 	}
@@ -51,7 +51,7 @@ mat2wide <- function(m, sym=TRUE, keep=NULL) {
 
 
 setMethod("distance", signature(x="SpatVector", y="ANY"), 
-	function(x, y, sequential=FALSE, pairs=FALSE, symmetrical=TRUE, ...) {
+	function(x, y, sequential=FALSE, pairs=FALSE, symmetrical=TRUE) {
 		if (sequential) {
 			return( x@ptr$distance_self(sequential))
 		}
@@ -73,7 +73,7 @@ setMethod("distance", signature(x="SpatVector", y="ANY"),
 
 
 setMethod("distance", signature(x="SpatVector", y="SpatVector"), 
-	function(x, y, pairwise=FALSE, ...) {
+	function(x, y, pairwise=FALSE) {
 		nx <- nrow(x)
 		ny <- nrow(y)
 		d <- x@ptr$distance_other(y@ptr, pairwise)
@@ -89,7 +89,7 @@ setMethod("distance", signature(x="SpatVector", y="SpatVector"),
 
 
 setMethod("distance", signature(x="matrix", y="matrix"), 
-	function(x, y, lonlat, pairwise=FALSE, ...) {
+	function(x, y, lonlat, pairwise=FALSE) {
 		if (missing(lonlat)) {
 			error("distance", "you must set lonlat to TRUE or FALSE")
 		}
@@ -105,7 +105,7 @@ setMethod("distance", signature(x="matrix", y="matrix"),
 
 
 setMethod("distance", signature(x="matrix", y="ANY"), 
-	function(x, y, lonlat, sequential=FALSE, ...) {
+	function(x, y, lonlat, sequential=FALSE) {
 		crs <- ifelse(lonlat, "+proj=longlat +datum=WGS84", 
 							  "+proj=utm +zone=1 +datum=WGS84")
 		x <- vect(x, crs=crs)
