@@ -30,7 +30,7 @@ setMethod("interpolate", signature(object="SpatRaster"),
 		cn <- colnames(r)
 		if (length(cn) == nl) names(out) <- make.names(cn, TRUE)
 
-		b <- writeStart(out, filename, overwrite, wopt)
+		b <- writeStart(out, filename, overwrite, wopt=wopt)
 		for (i in 1:b$n) {
 			xy <- xyFromCell(out, cellFromRowCol(out, b$row[i], 1):cellFromRowCol(out, b$row[i]+b$nrows[i]-1, nc))
 			colnames(xy) <- xyNames
