@@ -4,14 +4,15 @@
 	Z <- as.matrix(x, TRUE)
 	Z[is.nan(Z) | is.infinite(Z)] <- NA
 
-	z <- stats::na.omit(as.vector(Z))
+	z <- stats::na.omit(round(as.vector(Z), 12))
 	n <- length(z)
 	if (n == 0) error("plot", "no values")
+	uzi <- unique(z)
 	if (type == "depends") {
-		if (length(unique(z)) < 6) {
+		if (length(uzi) < 6) {
 			return (.as.raster.classes(out, x))
 		}
-	} else if (length(unique(z)) == 1) {
+	} else if (length(uzi) == 1) {
 		return (.as.raster.classes(out, x))
 	}
 
