@@ -61,6 +61,9 @@ parfun <- function(cls, data, fun, model, ...) {
 	if (!is.null(index)) {
 		r <- r[, index,drop=FALSE]
 	}
+	if (inherits(model, "gstat")) {
+		r <- r[,-c(1:2)]   # x, y
+	}
 	r
 }
 
@@ -144,7 +147,7 @@ setMethod("predict", signature(object="SpatRaster"),
 		} else {
 			cls <- NULL
 		}
-		b <- writeStart(out, filename, overwrite, wopt)
+		b <- writeStart(out, filename, overwrite, wopt=wopt)
 		for (i in 1:b$n) {
 			d <- readValues(object, b$row[i], b$nrows[i], 1, nc, TRUE, TRUE)
 			r <- .runModel(model, fun, d, nl, const, na.rm, index, cores=cores, cls=cls, ...)
