@@ -122,7 +122,11 @@ setReplaceMethod("[", c("SpatRaster","numeric", "missing"),
 			value <- i
 			value[] <- v
 		}
-		v <- values(x)
+		if (hasValues(x)) {
+			v <- values(x)
+		} else {
+			v <- matrix(NA, nrow=ncell(x), ncol=nlyr(x))
+		}
 		v[i,] <- value
 		values(x) <- v
 		x
@@ -130,6 +134,8 @@ setReplaceMethod("[", c("SpatRaster","numeric", "missing"),
 )
 
 
+
+
 setReplaceMethod("[", c("SpatRaster", "numeric", "numeric"),
 	function(x, i, j, value) {
 		i <- cellFromRowColCombine(x, i, j)
