@@ -1,44 +1,44 @@
 
 
 setMethod ("size" , "SpatVector", 
-	function(x, ...) {
+	function(x) {
 		x@ptr$size()
 	}
 )
 
 setMethod("geomtype", signature(x="SpatVector"), 
-	function(x, ...){ 
+	function(x){ 
 		x@ptr$type()
 	}
 )
 
 setMethod("datatype", signature(x="SpatVector"), 
-	function(x, ...){ 
+	function(x){ 
 		x@ptr$df$get_datatypes()
 	}
 )
 
 
 setMethod("is.lines", signature(x="SpatVector"), 
-	function(x, ...) {
+	function(x) {
 		geomtype(x) == "lines"
 	}
 )
 
 setMethod("is.polygons", signature(x="SpatVector"), 
-	function(x, ...) {
+	function(x) {
 		geomtype(x) == "polygons"
 	}
 )
 setMethod("is.points", signature(x="SpatVector"), 
-	function(x, ...) {
+	function(x) {
 		grepl("points", geomtype(x))
 	}
 )
 
 
 setMethod("geomtype", signature(x="Spatial"), 
-	function(x, ...){ 
+	function(x){ 
 		type <- sub("spatial", "", as.vector(tolower(class(x))))
 		type <- sub("dataframe", "", type)
 		if (type %in% c("grid", "pixels")) type <- "raster"
@@ -47,7 +47,7 @@ setMethod("geomtype", signature(x="Spatial"),
 )
 
 setMethod("geom", signature(x="SpatVector"), 
-	function(x, wkt=FALSE, df=FALSE, ...){
+	function(x, wkt=FALSE, df=FALSE){
 		if (wkt) {
 			x@ptr$getGeometryWKT()
 		} else {
@@ -63,6 +63,26 @@ setMethod("geom", signature(x="SpatVector"),
 	}
 )
 
+setMethod("coords", signature(x="SpatVector"), 
+	function(x, df=FALSE){
+		g <- x@ptr$coordinates()
+		g <- do.call(cbind, g)
+		colnames(g) <- c("x", "y")
+		if (df) {
+			data.frame(g)
+		} else {
+			g
+		}
+	}
+)
+
+setMethod("coords", signature(x="SpatRaster"), 
+	function(x, df=FALSE){
+		x <- as.points(x)
+		coordinates(x)
+	}
+)
+
 
 setMethod("dim", signature(x="SpatVector"), 
 	function(x){ 
@@ -71,7 +91,7 @@ setMethod("dim", signature(x="SpatVector"),
 )
 
 setMethod("as.data.frame", signature(x="SpatVector"), 
-	function(x, geom=FALSE, ...) {
+	function(x, geom=FALSE) {
 		d <- data.frame(x@ptr$getDF(), check.names=FALSE, fix.empty.names=FALSE, stringsAsFactors=FALSE)
 		colnames(d) <- x@ptr$names
 		if (geom) {
@@ -87,15 +107,15 @@ setMethod("as.data.frame", signature(x="SpatVector"),
 )
 
 setMethod("as.list", signature(x="SpatVector"), 
-	function(x, geom=FALSE, ...) {
-		as.list(as.data.frame(x, geom=geom, ...))
+	function(x, geom=FALSE) {
+		as.list(as.data.frame(x, geom=geom))
 	}
 )
 
 
 
 setMethod("area", signature(x="SpatVector"), 
-	function(x, ...) {
+	function(x) {
 		a <- x@ptr$area();
 		x <- messages(x, "area");
 		return(a)
@@ -104,9 +124,9 @@ setMethod("area", signature(x="SpatVector"),
 
 setMethod("perimeter", signature(x="SpatVector"), 
 	function(x) {
-		a <- x@ptr$length();
+		p <- x@ptr$length();
 		x <- messages(x, "length");
-		return(a)
+		return(p)
 	}
 )
 
@@ -119,7 +139,7 @@ setMethod("length", signature(x="SpatVector"),
 
 
 setMethod("fill", signature(x="SpatVector"), 
-	function(x, inverse=FALSE, ...) {
+	function(x, inverse=FALSE) {
 		if (inverse) {
 			x@ptr <- x@ptr$get_holes()
 		} else {
@@ -132,7 +152,7 @@ setMethod("fill", signature(x="SpatVector"),
 
 
 setMethod("centroids", signature(x="SpatVector"), 
-	function(x, ...) {
+	function(x) {
 		x@ptr <- x@ptr$centroid()
 		messages(x)
 	}
