@@ -30,6 +30,9 @@ class SpatDataFrame {
 		void setError(std::string s) { msg.setError(s); }
 		void addWarning(std::string s) { msg.addWarning(s); }
 		bool hasError() { return msg.has_error; }
+		bool hasWarning() { return msg.has_warning; }
+		std::string getWarnings() { return msg.getWarnings(); }
+		std::string getError() { return msg.getError(); }
 	
 		std::vector<std::string> names;
 		std::vector<unsigned> itype;
