@@ -1,4 +1,4 @@
-// Copyright (c) 2018-2020  Robert J. Hijmans
+// Copyright (c) 2018-2021  Robert J. Hijmans
 //
 // This file is part of the "spat" library.
 //
@@ -52,6 +52,8 @@ std::function<double(std::vector<double>&, bool)> getFun(std::string fun) {
 		theFun = vsd<double>;
 	} else if (fun == "std") {
 		theFun = vsdpop<double>;
+	} else if (fun == "first") {
+		theFun = vfirst<double>;
 	} else {
 		theFun = vmean<double>;
 	}
